pub struct FinancialEvents {
Show 33 fields pub shipment_event_list: Option<Vec<ShipmentEvent>>, pub shipment_settle_event_list: Option<Vec<ShipmentEvent>>, pub refund_event_list: Option<Vec<ShipmentEvent>>, pub guarantee_claim_event_list: Option<Vec<ShipmentEvent>>, pub chargeback_event_list: Option<Vec<ShipmentEvent>>, pub pay_with_amazon_event_list: Option<Vec<PayWithAmazonEvent>>, pub service_provider_credit_event_list: Option<Vec<SolutionProviderCreditEvent>>, pub retrocharge_event_list: Option<Vec<RetrochargeEvent>>, pub rental_transaction_event_list: Option<Vec<RentalTransactionEvent>>, pub product_ads_payment_event_list: Option<Vec<ProductAdsPaymentEvent>>, pub service_fee_event_list: Option<Vec<ServiceFeeEvent>>, pub seller_deal_payment_event_list: Option<Vec<SellerDealPaymentEvent>>, pub debt_recovery_event_list: Option<Vec<DebtRecoveryEvent>>, pub loan_servicing_event_list: Option<Vec<LoanServicingEvent>>, pub adjustment_event_list: Option<Vec<AdjustmentEvent>>, pub safet_reimbursement_event_list: Option<Vec<SafetReimbursementEvent>>, pub seller_review_enrollment_payment_event_list: Option<Vec<SellerReviewEnrollmentPaymentEvent>>, pub fba_liquidation_event_list: Option<Vec<FbaLiquidationEvent>>, pub coupon_payment_event_list: Option<Vec<CouponPaymentEvent>>, pub imaging_services_fee_event_list: Option<Vec<ImagingServicesFeeEvent>>, pub network_commingling_transaction_event_list: Option<Vec<NetworkComminglingTransactionEvent>>, pub affordability_expense_event_list: Option<Vec<AffordabilityExpenseEvent>>, pub affordability_expense_reversal_event_list: Option<Vec<AffordabilityExpenseEvent>>, pub removal_shipment_event_list: Option<Vec<RemovalShipmentEvent>>, pub removal_shipment_adjustment_event_list: Option<Vec<RemovalShipmentAdjustmentEvent>>, pub trial_shipment_event_list: Option<Vec<TrialShipmentEvent>>, pub tds_reimbursement_event_list: Option<Vec<TdsReimbursementEvent>>, pub adhoc_disbursement_event_list: Option<Vec<AdhocDisbursementEvent>>, pub tax_withholding_event_list: Option<Vec<TaxWithholdingEvent>>, pub charge_refund_event_list: Option<Vec<ChargeRefundEvent>>, pub failed_adhoc_disbursement_event_list: Option<Box<FailedAdhocDisbursementEventList>>, pub value_added_service_charge_event_list: Option<Box<ValueAddedServiceChargeEventList>>, pub capacity_reservation_billing_event_list: Option<Vec<CapacityReservationBillingEvent>>,
}
FinancialEvents : Contains all information related to a financial event.

Fields

shipment_event_list: Option<Vec<ShipmentEvent>>

A list of shipment event information.

shipment_settle_event_list: Option<Vec<ShipmentEvent>>

A list of ShipmentEvent items.

refund_event_list: Option<Vec<ShipmentEvent>>

A list of shipment event information.

guarantee_claim_event_list: Option<Vec<ShipmentEvent>>

A list of shipment event information.

chargeback_event_list: Option<Vec<ShipmentEvent>>

A list of shipment event information.

pay_with_amazon_event_list: Option<Vec<PayWithAmazonEvent>>

A list of events related to the seller’s Pay with Amazon account.

service_provider_credit_event_list: Option<Vec<SolutionProviderCreditEvent>>

A list of information about solution provider credits.

retrocharge_event_list: Option<Vec<RetrochargeEvent>>

A list of information about Retrocharge or RetrochargeReversal events.

rental_transaction_event_list: Option<Vec<RentalTransactionEvent>>

A list of rental transaction event information.

product_ads_payment_event_list: Option<Vec<ProductAdsPaymentEvent>>

A list of sponsored products payment events.

service_fee_event_list: Option<Vec<ServiceFeeEvent>>

A list of information about service fee events.

seller_deal_payment_event_list: Option<Vec<SellerDealPaymentEvent>>

A list of payment events for deal-related fees.

debt_recovery_event_list: Option<Vec<DebtRecoveryEvent>>

A list of debt recovery event information.

loan_servicing_event_list: Option<Vec<LoanServicingEvent>>

A list of loan servicing events.

adjustment_event_list: Option<Vec<AdjustmentEvent>>

A list of adjustment event information for the seller’s account.

safet_reimbursement_event_list: Option<Vec<SafetReimbursementEvent>>

A list of SAFETReimbursementEvents.

seller_review_enrollment_payment_event_list: Option<Vec<SellerReviewEnrollmentPaymentEvent>>

A list of information about fee events for the Early Reviewer Program.

fba_liquidation_event_list: Option<Vec<FbaLiquidationEvent>>

A list of FBA inventory liquidation payment events.

coupon_payment_event_list: Option<Vec<CouponPaymentEvent>>

A list of coupon payment event information.

imaging_services_fee_event_list: Option<Vec<ImagingServicesFeeEvent>>

A list of fee events related to Amazon Imaging services.

network_commingling_transaction_event_list: Option<Vec<NetworkComminglingTransactionEvent>>

A list of network commingling transaction events.

affordability_expense_event_list: Option<Vec<AffordabilityExpenseEvent>>

A list of expense information related to an affordability promotion.

affordability_expense_reversal_event_list: Option<Vec<AffordabilityExpenseEvent>>

A list of expense information related to an affordability promotion.

removal_shipment_event_list: Option<Vec<RemovalShipmentEvent>>

A list of removal shipment event information.

removal_shipment_adjustment_event_list: Option<Vec<RemovalShipmentAdjustmentEvent>>

A comma-delimited list of Removal shipmentAdjustment details for FBA inventory.

trial_shipment_event_list: Option<Vec<TrialShipmentEvent>>

A list of information about trial shipment financial events.

tds_reimbursement_event_list: Option<Vec<TdsReimbursementEvent>>

A list of TDSReimbursementEvent items.

adhoc_disbursement_event_list: Option<Vec<AdhocDisbursementEvent>>

A list of AdhocDisbursement events.

tax_withholding_event_list: Option<Vec<TaxWithholdingEvent>>

A list of TaxWithholding events.

charge_refund_event_list: Option<Vec<ChargeRefundEvent>>

A list of charge refund events.

failed_adhoc_disbursement_event_list: Option<Box<FailedAdhocDisbursementEventList>>value_added_service_charge_event_list: Option<Box<ValueAddedServiceChargeEventList>>capacity_reservation_billing_event_list: Option<Vec<CapacityReservationBillingEvent>>

A list of CapacityReservationBillingEvent events.

Implementations

Contains all information related to a financial event.